/* $Id: mesh.h,v 1.10 1998/03/13 14:01:04 scott Exp $ */

typedef struct{
  /* meshData structure.
   *
   * Contains an optionData structure and other data for performing the
   * stochastic mesh algorithm.
   *
   * meshPaths                  The first meshPath paths in the optionData
   *                            structure will be used for the mesh estimate.
   *                            The remaining paths only for the path estimate.
   *
   * valueIfHeld[time][path]    The value expected to be obtained by holding
   *                            the option instead of exercising it.
   *
   * value[time][path]          The value of the option.  The greater of the
   *                            value from holding and that from exercising.
   *
   * weightMeasure1		Measure of effective number of points averaged over
   *				as described by GCF.
   *
   * weightMeasure2		Another measure of effective number of points
   *
   * weightMeasure3	 same as 2, but don't divide by the max	
   *
   * distribution[time][path]   The height of the distribution from which points
   *				are selected at [time][path].  g from eq. 18.
   *
   * option                     An optionData structure holding the information
   *                            about the option payoffs and information about
   *                            the underlier paths upon which the other data
   *                            is derived.
   */

   int meshPaths;
   double **valueIfHeld;
   double **newValueIfHeld;
   double **value;
   double **newValue;
   double *weightMeasure1;
   double *weightMeasure2;
   double *weightMeasure3;
   double **distribution;
   double tolerance;
   optionData option;

  /* Permanent scratch variables. */
  double **tp, *sum;

}meshData;

void meshDataAllocate(meshData *md);
void meshSetFinalValue(meshData *md);
double meshCalculateEuropean(meshData *md); 
double meshWeight(meshData *md, int time, int toPath, int fromPath);
double meshValueIfHeld(meshData *md, int time, int path);
void meshDataFill(meshData *md);
double meshMeshEstimate(meshData *md);
double meshPathEstimate(meshData *md);
double meshControlledPathEstimate(meshData *md);

